Package: bioCancer
Title: Interactive Multi-Omics Cancers Data Visualization and Analysis
Version: 1.41.0
Date: 2024-02-14
Authors@R: person("Karim", "Mezhoud", role=c("aut", "cre"), email="kmezhoud@gmail.com")
Description: This package is a Shiny App to visualize and analyse interactively
    Multi-Assays of Cancer Genomic Data.
Depends: R (>= 4.1.0), radiant.data (>= 0.9.1), cBioPortalData, XML (>=
        3.98)
Imports: R.oo, R.methodsS3, DT (>= 0.3), dplyr (>= 0.7.2), tidyr, shiny
        (>= 1.0.5), AlgDesign (>= 1.1.7.3), import (>= 1.1.0), methods,
        AnnotationDbi, shinythemes, Biobase, geNetClassifier,
        org.Hs.eg.db, org.Bt.eg.db, DOSE, clusterProfiler, reactome.db,
        ReactomePA, DiagrammeR(<= 1.01), visNetwork, htmlwidgets, plyr,
        tibble, GO.db
Suggests: BiocStyle, prettydoc, rmarkdown, knitr, testthat (>= 0.10.0)
VignetteBuilder: knitr
URL: https://kmezhoud.github.io/bioCancer/
BugReports: https://github.com/kmezhoud/bioCancer/issues
License: AGPL-3 | file LICENSE
LazyData: true
biocViews: GUI, DataRepresentation, Network, MultipleComparison,
        Pathways, Reactome, Visualization,GeneExpression,GeneTarget
RoxygenNote: 7.3.1
Encoding: UTF-8
git_url: https://git.bioconductor.org/packages/bioCancer
git_branch: devel
git_last_commit: adaad4e
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 21:30:18 UTC; biocbuild
Author: Karim Mezhoud [aut, cre]
Maintainer: Karim Mezhoud <kmezhoud@gmail.com>
