# to avoid 'no visible binding for global variable' NOTE
globalVariables(c("r_data", "V1", "input", "p", "incProgress", "setNames", "tags", "br",
                  "stats","tagList","Freq","a","b","d", "e","GeneList", "cgds", "session",
                  "setNames", "stats", "SubMegaGeneList","getMegaProfData", "cbind.na",
                  "saveWidget", "downloadLink", "dbListTables", "dbConnect", "dbDriver",
                  "dbSendQuery", "dbfile", "dbClearResult", "dbWriteTable", "direction",
                  "dbGetQuery", "dbDisconnect", ".", "pull"))
