> Show Mutations Data in Table

Mutation panel displays informations related to gene list mutations. User needs to select a Case`_all` or Case`_sequenced`, and a `genetic Profile` with `mutations`.

#### Select variables to show

By default all columns in the data are shown. Click on any variable to focus on it alone. To select several variables use the SHIFT and ARROW keys on your keyboard. On a mac the CMD key can also be used to select multiple variables. The same effect is achieved on windows using the CTRL key. To select all variable use CTRL-A (or CMD-A on mac).

#### Load Gene List
User can upload gene list examples or upload own gene list.

When user selects `examples` and clic on `Load examples` button, the gene list examples is loaded in DropDown Gene List.

When User selects  `clipboard`, it is possible to copy own gene list from text file (gene symbol by line) and clic on  `Paste Gene List` button. The gene List will be named  `Genes` in DropDown Gene List.

#### Load Mutations to Datasets

It is interesting to get any statistics analysis or transformation with genetic profiles. Any table from `Mutation` panel can be loaded to `Processing` panel by checking `Load Mutations to Datasets` and press the button. The data frame will be named `MutData`.
