> Save, reset, or quit

This page provides another option to save the state of the app to disk. See the help file for the Data > Manage page for more details. To reset the app to a _clean_ state press the `Reset` button. Finally, to cleanly exit from Radiant click the `Quit` button.
