% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Enrich.R
\name{getSequensed_SampleSize}
\alias{getSequensed_SampleSize}
\title{get samples size of sequensed genes}
\usage{
getSequensed_SampleSize(StudiesID)
}
\arguments{
\item{StudiesID}{Studies ID as a vector}
}
\value{
dataframe with sample size for each selected study.
}
\description{
get samples size of sequensed genes
}
\examples{
\dontrun{
 sampleSize <- getSequensed_SampleSize(input$StudiesIDCircos)
}

}
